@@ -636,7 +636,7 @@ class Diot(dict):
             import rtoml  # type: ignore[import]
         except ImportError as exc:  # pragma: no cover
             raise ImportError(
-                "You need toml installed to export Diot as toml."
+                "You need rtoml installed to export Diot as toml."
             ) from exc
         toml_dump = self.to_dict()
         if not filename:
@@ -837,9 +837,10 @@ class OrderedDiot(Diot):
     def pop(self, name: str, *value) -> Any:
         ret = super().pop(name, *value)
         name = self.__diot__["keymaps"].get(name, name)
-        del self.__diot__["orderedkeys"][
-            self.__diot__["orderedkeys"].index(name)
-        ]
+        if name in self.__diot__["orderedkeys"]:
+            del self.__diot__["orderedkeys"][
+                self.__diot__["orderedkeys"].index(name)
+            ]
         return ret
 
     def __reversed__(self) -> Iterable:  # type: ignore[override]
